bayespy.inference.vmp.nodes.multinomial.MultinomialMoments.add_converter
========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.multinomial

.. automethod:: MultinomialMoments.add_converter